/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

package org.elasticsearch.client.watcher;

import org.elasticsearch.xcontent.ConstructingObjectParser;
import org.elasticsearch.xcontent.ParseField;
import org.elasticsearch.xcontent.XContentParser;

import java.io.IOException;
import java.util.Objects;

/**
 * Response from an 'activate watch' request.
 */
public final class ActivateWatchResponse {

    private static final ParseField STATUS_FIELD = new ParseField("status");
    private static final ConstructingObjectParser<ActivateWatchResponse, Void> PARSER = new ConstructingObjectParser<>(
        "activate_watch_response",
        true,
        a -> new ActivateWatchResponse((WatchStatus) a[0])
    );

    static {
        PARSER.declareObject(ConstructingObjectParser.constructorArg(), (parser, context) -> WatchStatus.parse(parser), STATUS_FIELD);
    }

    private final WatchStatus status;

    public ActivateWatchResponse(WatchStatus status) {
        this.status = status;
    }

    public WatchStatus getStatus() {
        return status;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ActivateWatchResponse that = (ActivateWatchResponse) o;
        return Objects.equals(status, that.status);
    }

    @Override
    public int hashCode() {
        return Objects.hash(status);
    }

    public static ActivateWatchResponse fromXContent(XContentParser parser) throws IOException {
        return PARSER.parse(parser, null);
    }
}
